==> delete_orphaned_non_reusable_blocks-1.0.0.tar.gz: delete_orphaned_non_reusable_blocks/src/Form/DeleteOrphanedNonReusableBlocksForm.php <==
<?php

namespace Drupal\delete_orphaned_non_reusable_blocks\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DeleteOrphanedNonReusableBlocksForm.
 */
class DeleteOrphanedNonReusableBlocksForm extends FormBase {

  /**
   * Number of orphans that will be deleted.
   *
   * @var int
   */
  protected $orphanCount;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_orphaned_non_reusable_blocks_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $orphans = $this->getOrphans();

    $this->orphanCount = count($orphans);

    $form['warning1'] = [
      '#markup' => '<p>' . $this->t('Warning: This functonality is experimental and for use only when you know what your are doing.') . '</p>',
    ];

    $form['warning2'] = [
      '#markup' => '<p>' . $this->t('Do not under any circumstances use this on a production system. Take a database backup before use. You have been warned.') . '</p>',
    ];

    $header = [
      'block_id' => t('Block ID'),
      'block_uuid' => t('UUID'),
      'bundle' => t('Bundle'),
    ];

    $form['orphan_table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $orphans,
      '#empty' => t('No orphaned non reusable block content found'),
    ];

    if ($this->orphanCount) {

      $form['info'] = [
        '#markup' => '<p>' . $this->t('Confirming this action will delete %count orphaned non reusable block content entities from the system.', ['%count' => $this->orphanCount]) . '</p>',
      ];

      $form['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Delete orphans'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect('delete_orphaned_non_reusable_blocks.confirm', [ 
      'orphanCount' => $this->orphanCount
    ]);
  }

  private function getOrphans() {

    // Get the inline block usage service
    $srvUsage = \Drupal::service('inline_block.usage');

    // Get all block content ids
    $ids = \Drupal::entityQuery('block_content')->execute();

    $orphans = [];

    // Loop all fids and load files by fid
    foreach ($ids as $id) {

      $block = \Drupal\block_content\Entity\BlockContent::load($id);

      // If this is a non reusable block then it's been added in layout builder
      if (!$block->isReusable()) {

        // Get the usage for the block
        $usage = $srvUsage->getUsage(intval($id));

        // Check if block not used and if not delete it
        if (empty($usage)) {
    
          $orphans[] = [
            'block_id' => $id,
            'block_uuid' =>  $block->uuid(),
            'bundle' => $block->bundle(),
          ];
        }
      }
    }

    return $orphans;
  }
}

==> delete_orphaned_non_reusable_blocks-1.0.1.tar.gz: delete_orphaned_non_reusable_blocks/src/Form/DeleteOrphanedNonReusableBlocksForm.php <==
<?php

namespace Drupal\delete_orphaned_non_reusable_blocks\Form;

use Drupal\block_content\Entity\BlockContent;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DeleteOrphanedNonReusableBlocksForm.
 */
class DeleteOrphanedNonReusableBlocksForm extends FormBase {

  /**
   * Number of orphans that will be deleted.
   *
   * @var int
   */
  protected $orphanCount;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_orphaned_non_reusable_blocks_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $orphans = $this->getOrphans();

    $this->orphanCount = count($orphans);

    $form['warning1'] = [
      '#markup' => '<p>' . $this->t('Warning: This functionality is experimental and for use only when you know what you are doing.') . '</p>',
    ];

    $form['warning2'] = [
      '#markup' => '<p>' . $this->t('Do not under any circumstances use this on a production system. Take a database backup before use. You have been warned.') . '</p>',
    ];

    $header = [
      'block_id' => $this->t('Block ID'),
      'block_uuid' => $this->t('UUID'),
      'bundle' => $this->t('Bundle'),
    ];

    $form['orphan_table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $orphans,
      '#empty' => $this->t('No orphaned non reusable block content found'),
    ];

    if ($this->orphanCount) {

      $form['info'] = [
        '#markup' => '<p>' . $this->t('Confirming this action will delete %count orphaned non reusable block content entities from the system.', ['%count' => $this->orphanCount]) . '</p>',
      ];

      $form['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Delete orphans'),
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRedirect('delete_orphaned_non_reusable_blocks.confirm', [
      'orphanCount' => $this->orphanCount,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  private function getOrphans() {

    // Get the inline block usage service.
    $srvUsage = \Drupal::service('inline_block.usage');

    // Get all block content ids.
    $ids = \Drupal::entityQuery('block_content')->execute();

    $orphans = [];

    // Loop all fids and load files by fid.
    foreach ($ids as $id) {

      $block = BlockContent::load($id);

      // If this is a non-reusable block then it has been added in layout
      // builder.
      if (!$block->isReusable()) {

        // Get the usage for the block.
        $usage = $srvUsage->getUsage(intval($id));

        // Check if block not used and if not delete it.
        if (empty($usage)) {

          $orphans[] = [
            'block_id' => $id,
            'block_uuid' => $block->uuid(),
            'bundle' => $block->bundle(),
          ];
        }
      }
    }

    return $orphans;
  }

}
